aboutsummaryrefslogtreecommitdiff
path: root/src/dotty/tools/dotc/core/Scopes.scala
diff options
context:
space:
mode:
authorMartin Odersky <odersky@gmail.com>2013-01-21 12:43:11 +0100
committerMartin Odersky <odersky@gmail.com>2013-01-21 12:43:11 +0100
commite59b8822f53fa6fad057ac9642d31e4026800bf5 (patch)
tree644848889cf7479d43b95e11a224e4a9373ff5e3 /src/dotty/tools/dotc/core/Scopes.scala
parenta14284769027bc81e48ccfa3379c6448d1399dfc (diff)
downloaddotty-e59b8822f53fa6fad057ac9642d31e4026800bf5.tar.gz
dotty-e59b8822f53fa6fad057ac9642d31e4026800bf5.tar.bz2
dotty-e59b8822f53fa6fad057ac9642d31e4026800bf5.zip
Big renaming to drop Reference(d) as a terminology and use Denotation instead. previous Denotations (which already were a subclass) are renamed to SymDenotations.
Diffstat (limited to 'src/dotty/tools/dotc/core/Scopes.scala')
-rw-r--r--src/dotty/tools/dotc/core/Scopes.scala11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/dotty/tools/dotc/core/Scopes.scala b/src/dotty/tools/dotc/core/Scopes.scala
index f9fa69c1c..98f0b6390 100644
--- a/src/dotty/tools/dotc/core/Scopes.scala
+++ b/src/dotty/tools/dotc/core/Scopes.scala
@@ -11,7 +11,8 @@ import Names._
import Periods._
import Decorators._
import Contexts._
-import Referenceds._
+import Denotations._
+import SymDenotations.NoDenotation
object Scopes {
@@ -194,12 +195,12 @@ object Scopes {
def next(): Symbol = { val r = e.sym; e = lookupNextEntry(e); r }
}
- /** The reference set of all the symbols with given name in this scope */
- def refsNamed(name: Name)(implicit ctx: Context): ReferencedSet = {
- var syms: ReferencedSet = NoRefd
+ /** The denotation set of all the symbols with given name in this scope */
+ def denotsNamed(name: Name)(implicit ctx: Context): DenotationSet = {
+ var syms: DenotationSet = NoDenotation
var e = lookupEntry(name)
while (e != null) {
- syms = syms union e.sym.deref
+ syms = syms union e.sym.denot
e = lookupNextEntry(e)
}
syms